@@ -35,17 +35,19 @@ public:
   virtual ~Box_DB_Table_Relationships();
 
   void init(); //avoid duplication in constructors.
-  
+
   virtual void save_to_document(); //override.
 
 protected:
-  virtual void fill_from_database();
+  virtual bool fill_from_database();
 
   //Signal handlers:
   virtual void on_adddel_user_activated(const Gtk::TreeModel::iterator& row, guint col);
   virtual void on_adddel_user_changed(const Gtk::TreeModel::iterator& row, guint col);
-
-  guint m_colName, m_colFromField, m_colToTable, m_colToField;
+  virtual void on_adddel_user_requested_delete(const Gtk::TreeModel::iterator& rowStart, const Gtk::TreeModel::iterator& rowEnd);
+  virtual void on_adddel_user_added(const Gtk::TreeModel::iterator& row);
+  
+  guint m_colName, m_colTitle, m_colFromField, m_colToTable, m_colToField, m_colAutoCreate;
 
   mutable AddDel_WithButtons m_AddDel; //mutable because its get_ methods aren't const.
   Gtk::Button m_Button_Guess;
